@@ -1,10 +1,11 @@
 package Pcore::App::PSGI::Role;
 
-use Pcore qw[-role];
+use Pcore -role;
 
 package Pcore::App::PSGI;
 
-use Pcore qw[-class];
+use Pcore -class;
+use Pcore::Util::Scalar qw[is_glob];
 use Term::ANSIColor qw[:constants];
 use Plack::Builder qw[];
 use Pcore::AppX::HasAppX;
@@ -46,8 +47,8 @@ around cli_opt => sub ( $orig, $self ) {
     };
 
     $opt->{server} = {
-        desc => 'allowed servers: "Starman", "Feersum", "Thrall". Defaults: "Feersum". Feersum is recommended to run behind nginx.',
-        isa  => qr/\AStarman|Feersum|Thrall|Twiggy.*|Starlet|Monoceros\z/sm,
+        desc => 'allowed servers: "Starman", "Feersum". Defaults: "Feersum". Feersum is recommended to run behind nginx.',
+        isa  => qr/\AStarman|Feersum|Twiggy.*|Starlet|Monoceros\z/sm,
     };
 
     $opt->{workers} = {
@@ -85,7 +86,7 @@ sub _app ($self) {
                 catch {
                     my $e = shift;
 
-                    $e->send_log;
+                    $e->sendlog;
 
                     return [500];    # return 500 - Interenal Server Error
                 };
@@ -107,7 +108,7 @@ sub _app ($self) {
                                 $content_length += length;
                             }
                         }
-                        elsif ( P->scalar->is_glob( $res->[2] ) ) {
+                        elsif ( is_glob( $res->[2] ) ) {
                             $content_length = ( -s $res->[2] ) - tell $res->[2];
                         }
                         else {
@@ -212,9 +213,9 @@ sub _deploy_nginx_cfg ($self) {
     my $params = {
         app_name          => $self->name,
         app_dir           => $self->app_dir,
-        resources_dir     => $PROC->res->get_storage( 'www', 'dist' ),
-        log_dir           => $PROC->{LOG_DIR},
-        use_ssl           => 0,                                          # TODO
+        resources_dir     => $ENV->res->get_storage( 'www', 'dist' ),
+        log_dir           => $ENV->{LOG_DIR},
+        use_ssl           => 0,                                         # TODO
         server_name       => $self->cfg->{PSGI}->{SERVER}->{name},
         ctrl_tmpl         => [],
         x_accel_locations => {},
@@ -284,7 +285,7 @@ sub store_runtime_cfg ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 224                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 225                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
