@@ -1,6 +1,6 @@
-package Pcore::PSGI v0.1.2;
+package Pcore::PSGI v0.1.3;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 1;
 __END__
