@@ -1,6 +1,6 @@
 package Pcore::PSGI::Middleware::Example;
 
-use Pcore qw[-class];
+use Pcore -class;
 extends qw[Pcore::PSGI::Middleware];
 
 sub call {
